@@ -58,7 +58,7 @@ const MAP: &[ColorMap] = &[
 
 fn main() {
     let a = app::App::default().with_scheme(app::Scheme::Gtk);
-    let theme = ColorTheme::from_colormap(MAP);
+    let theme = ColorTheme::new(MAP);
     theme.apply();
     let mut win = window::Window::default().with_size(400, 300);
     let mut btn = button::Button::new(160, 200, 80, 40, "Hello");
